==> beans-ddi-lifecycle-1.0.0-20130314.181714-4-sources.jar: org/openmetadata/beans/ddi/lifecycle/simpledc/impl/ElementGroupBeanImpl.java <==
package org.openmetadata.beans.ddi.lifecycle.simpledc.impl;

import org.openmetadata.beans.ddi.lifecycle.simpledc.ElementGroupBean;
import org.openmetadata.beans.ddi.lifecycle.simpledc.ElementValueBean;
import org.openmetadata.beans.notification.ChangeListener;

public class ElementGroupBeanImpl implements ElementGroupBean {

	private ElementValueBeanImpl title;
	private ElementValueBeanImpl creator;
	private ElementValueBeanImpl subject;
	private ElementValueBeanImpl description;
	private ElementValueBeanImpl publisher;
	private ElementValueBeanImpl contributor;
	private ElementValueBeanImpl date;
	private ElementValueBeanImpl type;
	private ElementValueBeanImpl format;
	private ElementValueBeanImpl identifier;
	private ElementValueBeanImpl source;
	private ElementValueBeanImpl language;
	private ElementValueBeanImpl relation;
	private ElementValueBeanImpl coverage;
	private ElementValueBeanImpl rights;

	public ElementGroupBeanImpl(ChangeListener changeListener) {
		title = new ElementValueBeanImpl(changeListener);
		creator = new ElementValueBeanImpl(changeListener);
		subject = new ElementValueBeanImpl(changeListener);
		description = new ElementValueBeanImpl(changeListener);
		publisher = new ElementValueBeanImpl(changeListener);
		contributor = new ElementValueBeanImpl(changeListener);
		date = new ElementValueBeanImpl(changeListener);
		type = new ElementValueBeanImpl(changeListener);
		format = new ElementValueBeanImpl(changeListener);
		identifier = new ElementValueBeanImpl(changeListener);
		source = new ElementValueBeanImpl(changeListener);
		language = new ElementValueBeanImpl(changeListener);
		relation = new ElementValueBeanImpl(changeListener);
		coverage = new ElementValueBeanImpl(changeListener);
		rights = new ElementValueBeanImpl(changeListener);
	}

	@Override
	public ElementValueBean getTitle() {
		return title;
	}

	@Override
	public ElementValueBean getCreator() {
		return creator;
	}

	@Override
	public ElementValueBean getSubject() {
		return subject;
	}

	@Override
	public ElementValueBean getDescription() {
		return description;
	}

	@Override
	public ElementValueBean getPublisher() {
		return publisher;
	}

	@Override
	public ElementValueBean getContributor() {
		return contributor;
	}

	@Override
	public ElementValueBean getDate() {
		return date;
	}

	@Override
	public ElementValueBean getType() {
		return type;
	}

	@Override
	public ElementValueBean getFormat() {
		return format;
	}

	@Override
	public ElementValueBean getIdentifier() {
		return identifier;
	}

	@Override
	public ElementValueBean getSource() {
		return source;
	}

	@Override
	public ElementValueBean getLanguage() {
		return language;
	}

	@Override
	public ElementValueBean getRelation() {
		return relation;
	}

	@Override
	public ElementValueBean getCoverage() {
		return coverage;
	}

	@Override
	public ElementValueBean getRights() {
		return rights;
	}

}

==> beans-ddi-lifecycle-1.0.0-20130315.185903-7-sources.jar: org/openmetadata/beans/ddi/lifecycle/simpledc/impl/ElementGroupBeanImpl.java <==
package org.openmetadata.beans.ddi.lifecycle.simpledc.impl;

import org.openmetadata.beans.ddi.lifecycle.simpledc.ElementGroupBean;
import org.openmetadata.beans.notification.ChangeListener;

public class ElementGroupBeanImpl implements ElementGroupBean {

	private ElementValueBeanImpl title;
	private ElementValueBeanImpl creator;
	private ElementValueBeanImpl subject;
	private ElementValueBeanImpl description;
	private ElementValueBeanImpl publisher;
	private ElementValueBeanImpl contributor;
	private ElementValueBeanImpl date;
	private ElementValueBeanImpl type;
	private ElementValueBeanImpl format;
	private ElementValueBeanImpl identifier;
	private ElementValueBeanImpl source;
	private ElementValueBeanImpl language;
	private ElementValueBeanImpl relation;
	private ElementValueBeanImpl coverage;
	private ElementValueBeanImpl rights;

	public ElementGroupBeanImpl(ChangeListener changeListener) {
		title = new ElementValueBeanImpl(changeListener);
		creator = new ElementValueBeanImpl(changeListener);
		subject = new ElementValueBeanImpl(changeListener);
		description = new ElementValueBeanImpl(changeListener);
		publisher = new ElementValueBeanImpl(changeListener);
		contributor = new ElementValueBeanImpl(changeListener);
		date = new ElementValueBeanImpl(changeListener);
		type = new ElementValueBeanImpl(changeListener);
		format = new ElementValueBeanImpl(changeListener);
		identifier = new ElementValueBeanImpl(changeListener);
		source = new ElementValueBeanImpl(changeListener);
		language = new ElementValueBeanImpl(changeListener);
		relation = new ElementValueBeanImpl(changeListener);
		coverage = new ElementValueBeanImpl(changeListener);
		rights = new ElementValueBeanImpl(changeListener);
	}

	@Override
	public ElementValueBeanImpl getTitle() {
		return title;
	}

	@Override
	public ElementValueBeanImpl getCreator() {
		return creator;
	}

	@Override
	public ElementValueBeanImpl getSubject() {
		return subject;
	}

	@Override
	public ElementValueBeanImpl getDescription() {
		return description;
	}

	@Override
	public ElementValueBeanImpl getPublisher() {
		return publisher;
	}

	@Override
	public ElementValueBeanImpl getContributor() {
		return contributor;
	}

	@Override
	public ElementValueBeanImpl getDate() {
		return date;
	}

	@Override
	public ElementValueBeanImpl getType() {
		return type;
	}

	@Override
	public ElementValueBeanImpl getFormat() {
		return format;
	}

	@Override
	public ElementValueBeanImpl getIdentifier() {
		return identifier;
	}

	@Override
	public ElementValueBeanImpl getSource() {
		return source;
	}

	@Override
	public ElementValueBeanImpl getLanguage() {
		return language;
	}

	@Override
	public ElementValueBeanImpl getRelation() {
		return relation;
	}

	@Override
	public ElementValueBeanImpl getCoverage() {
		return coverage;
	}

	@Override
	public ElementValueBeanImpl getRights() {
		return rights;
	}

}
